@@ -1,25 +1,25 @@
 /*
-   SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "archivemailkernel.h"
 
+#include <AkonadiCore/changerecorder.h>
+#include <AkonadiCore/entitymimetypefiltermodel.h>
+#include <AkonadiCore/entitytreemodel.h>
+#include <AkonadiCore/session.h>
 #include <KIdentityManagement/kidentitymanagement/identitymanager.h>
+#include <KSharedConfig>
 #include <MailCommon/FolderCollectionMonitor>
 #include <MailCommon/JobScheduler>
-#include <AkonadiCore/session.h>
-#include <AkonadiCore/entitytreemodel.h>
-#include <AkonadiCore/entitymimetypefiltermodel.h>
-#include <AkonadiCore/changerecorder.h>
-#include <KSharedConfig>
 
 ArchiveMailKernel::ArchiveMailKernel(QObject *parent)
     : QObject(parent)
 {
     mIdentityManager = new KIdentityManagement::IdentityManager(true, this);
-    Akonadi::Session *session = new Akonadi::Session("Archive Mail Kernel ETM", this);
+    auto session = new Akonadi::Session("Archive Mail Kernel ETM", this);
     mFolderCollectionMonitor = new MailCommon::FolderCollectionMonitor(session, this);
 
     mFolderCollectionMonitor->monitor()->setChangeRecordingEnabled(false);
@@ -112,11 +112,11 @@ Akonadi::Collection::Id ArchiveMailKernel::lastSelectedFolder()
 
 void ArchiveMailKernel::setLastSelectedFolder(Akonadi::Collection::Id col)
 {
-    Q_UNUSED(col);
+    Q_UNUSED(col)
 }
 
 void ArchiveMailKernel::expunge(Akonadi::Collection::Id col, bool sync)
 {
-    Q_UNUSED(col);
-    Q_UNUSED(sync);
+    Q_UNUSED(col)
+    Q_UNUSED(sync)
 }
