@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,12 @@
 #ifndef FOLLOWUPREMINDERMANAGER_H
 #define FOLLOWUPREMINDERMANAGER_H
 
-#include <QObject>
-#include <KSharedConfig>
 #include <AkonadiCore/Item>
+#include <KSharedConfig>
+#include <QObject>
 #include <QPointer>
-namespace FollowUpReminder {
+namespace FollowUpReminder
+{
 class FollowUpReminderInfo;
 }
 class FollowUpReminderNoAnswerDialog;
@@ -20,13 +21,14 @@ class FollowUpReminderManager : public QObject
     Q_OBJECT
 public:
     explicit FollowUpReminderManager(QObject *parent = nullptr);
-    ~FollowUpReminderManager();
+    ~FollowUpReminderManager() override;
 
     void load(bool forceReloadConfig = false);
     void addReminder(FollowUpReminder::FollowUpReminderInfo *reminder); // takes ownership
     void checkFollowUp(const Akonadi::Item &item, const Akonadi::Collection &col);
 
     Q_REQUIRED_RESULT QString printDebugInfo() const;
+
 private:
     Q_DISABLE_COPY(FollowUpReminderManager)
     void slotCheckFollowUpFinished(const QString &messageId, Akonadi::Item::Id id);
