@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef SENDLATERCONFIGUREDIALOG_H
 #define SENDLATERCONFIGUREDIALOG_H
 
-#include <QDialog>
 #include <AkonadiCore/Item>
+#include <QDialog>
 class SendLaterWidget;
 class SendLaterConfigureDialog : public QDialog
 {
     Q_OBJECT
 public:
     explicit SendLaterConfigureDialog(QWidget *parent = nullptr);
-    ~SendLaterConfigureDialog();
+    ~SendLaterConfigureDialog() override;
 
     Q_REQUIRED_RESULT QVector<Akonadi::Item::Id> messagesToRemove() const;
 
