@@ -1,35 +1,34 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "refreshsettingscleanuppage.h"
-#include <QHBoxLayout>
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <QHBoxLayout>
 #include <QPushButton>
 #include <QRegularExpression>
 
 RefreshSettingsCleanupPage::RefreshSettingsCleanupPage(QWidget *parent)
     : QWidget(parent)
 {
-    auto *mainLayout = new QHBoxLayout(this);
+    auto mainLayout = new QHBoxLayout(this);
     mainLayout->setObjectName(QStringLiteral("mainLayout"));
     mainLayout->setContentsMargins({});
-    QPushButton *button = new QPushButton(i18n("Clean"), this);
+    auto button = new QPushButton(i18n("Clean"), this);
     button->setObjectName(QStringLiteral("button"));
     mainLayout->addWidget(button);
     connect(button, &QPushButton::clicked, this, &RefreshSettingsCleanupPage::cleanSettings);
 }
 
-RefreshSettingsCleanupPage::~RefreshSettingsCleanupPage()
-= default;
+RefreshSettingsCleanupPage::~RefreshSettingsCleanupPage() = default;
 
 void RefreshSettingsCleanupPage::cleanSettings()
 {
-    const QStringList configNameFiles {QStringLiteral("kmail2rc"), QStringLiteral("kontactrc")};
-    for (const QString &configName: configNameFiles) {
+    const QStringList configNameFiles{QStringLiteral("kmail2rc"), QStringLiteral("kontactrc")};
+    for (const QString &configName : configNameFiles) {
         initCleanupFolderSettings(configName);
         initCleanupFiltersSettings(configName);
         initCleanDialogSettings(configName);
