@@ -14,7 +14,7 @@ class KActionMenuTransportTest : public QObject
     Q_OBJECT
 public:
     explicit KActionMenuTransportTest(QObject *parent = nullptr);
-    ~KActionMenuTransportTest();
+    ~KActionMenuTransportTest() override;
 private Q_SLOTS:
     void shouldHaveDefaultValue();
 };
