@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2009-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2009-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,11 @@
 #include "collectiontemplatespage.h"
 #include <MailCommon/CollectionTemplatesWidget>
 
-#include <MailCommon/MailKernel>
-#include <MailCommon/FolderSettings>
-#include <TemplateParser/TemplatesConfiguration>
 #include "templatesconfiguration_kfg.h"
 #include <AkonadiCore/collection.h>
+#include <MailCommon/FolderSettings>
+#include <MailCommon/MailKernel>
+#include <TemplateParser/TemplatesConfiguration>
 
 #include <KLocalizedString>
 
@@ -26,18 +26,16 @@ CollectionTemplatesPage::CollectionTemplatesPage(QWidget *parent)
     init();
 }
 
-CollectionTemplatesPage::~CollectionTemplatesPage()
-= default;
+CollectionTemplatesPage::~CollectionTemplatesPage() = default;
 
 bool CollectionTemplatesPage::canHandle(const Collection &collection) const
 {
-    return !CommonKernel->isSystemFolderCollection(collection)
-           || CommonKernel->isMainFolderCollection(collection);
+    return !CommonKernel->isSystemFolderCollection(collection) || CommonKernel->isMainFolderCollection(collection);
 }
 
 void CollectionTemplatesPage::init()
 {
-    auto *topLayout = new QVBoxLayout(this);
+    auto topLayout = new QVBoxLayout(this);
     topLayout->setContentsMargins({});
     mCollectionTemplateWidget = new MailCommon::CollectionTemplatesWidget(this);
     topLayout->addWidget(mCollectionTemplateWidget);
