@@ -1,33 +1,33 @@
 /*
    SPDX-FileCopyrightText: 2009 Klarälvdalens Datakonsult AB
-   SPDX-FileCopyrightText: 2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2020-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 */
 
 #include "archivefolderdialog.h"
 
-#include <MailCommon/BackupJob>
 #include "kmkernel.h"
 #include "kmmainwidget.h"
+#include <MailCommon/BackupJob>
 #include <MailCommon/FolderRequester>
 #include <MessageViewer/MessageViewerUtil>
 
 #include <AkonadiCore/Collection>
 
 #include <KLocalizedString>
-#include <QComboBox>
-#include <KUrlRequester>
 #include <KMessageBox>
 #include <KSeparator>
+#include <KUrlRequester>
+#include <QComboBox>
 
-#include <QLabel>
 #include <QCheckBox>
-#include <QGridLayout>
-#include <QStandardPaths>
-#include <QMimeDatabase>
 #include <QDialogButtonBox>
+#include <QGridLayout>
+#include <QLabel>
+#include <QMimeDatabase>
 #include <QPushButton>
+#include <QStandardPaths>
 #include <QVBoxLayout>
 
 using namespace KMail;
@@ -40,9 +40,8 @@ QString ArchiveFolderDialog::standardArchivePath(const QString &folderName)
     if (!dir.exists()) {
         currentPath = QDir::homePath();
     }
-    return currentPath + QLatin1Char('/')
-           +i18nc("Start of the filename for a mail archive file",
-                  "Archive") + QLatin1Char('_') + folderName + QLatin1Char('_') + QDate::currentDate().toString(Qt::ISODate) + QLatin1String(".tar.bz2");
+    return currentPath + QLatin1Char('/') + i18nc("Start of the filename for a mail archive file", "Archive") + QLatin1Char('_') + folderName + QLatin1Char('_')
+        + QDate::currentDate().toString(Qt::ISODate) + QLatin1String(".tar.bz2");
 }
 
 ArchiveFolderDialog::ArchiveFolderDialog(QWidget *parent)
@@ -51,8 +50,8 @@ ArchiveFolderDialog::ArchiveFolderDialog(QWidget *parent)
 {
     setObjectName(QStringLiteral("archive_folder_dialog"));
     setWindowTitle(i18nc("@title:window for archiving a folder", "Archive Folder"));
-    auto *topLayout = new QVBoxLayout(this);
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto topLayout = new QVBoxLayout(this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
     mOkButton = buttonBox->button(QDialogButtonBox::Ok);
     mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
     connect(buttonBox, &QDialogButtonBox::accepted, this, &ArchiveFolderDialog::slotAccepted);
@@ -60,17 +59,17 @@ ArchiveFolderDialog::ArchiveFolderDialog(QWidget *parent)
     mOkButton->setDefault(true);
     mOkButton->setText(i18nc("@action", "Archive"));
     setModal(true);
-    QWidget *mainWidget = new QWidget(this);
+    auto mainWidget = new QWidget(this);
     topLayout->addWidget(mainWidget);
     topLayout->addWidget(buttonBox);
-    auto *mainLayout = new QGridLayout(mainWidget);
+    auto mainLayout = new QGridLayout(mainWidget);
     mainLayout->setContentsMargins({});
 
     int row = 0;
 
     // TODO: Explanation label
 
-    QLabel *folderLabel = new QLabel(i18n("&Folder:"), mainWidget);
+    auto folderLabel = new QLabel(i18n("&Folder:"), mainWidget);
     mainLayout->addWidget(folderLabel, row, 0);
     mFolderRequester = new FolderRequester(mainWidget);
     mFolderRequester->setMustBeReadWrite(false);
@@ -80,7 +79,7 @@ ArchiveFolderDialog::ArchiveFolderDialog(QWidget *parent)
     mainLayout->addWidget(mFolderRequester, row, 1);
     row++;
 
-    QLabel *formatLabel = new QLabel(i18n("F&ormat:"), mainWidget);
+    auto formatLabel = new QLabel(i18n("F&ormat:"), mainWidget);
     mainLayout->addWidget(formatLabel, row, 0);
     mFormatComboBox = new QComboBox(mainWidget);
     formatLabel->setBuddy(mFormatComboBox);
@@ -95,7 +94,7 @@ ArchiveFolderDialog::ArchiveFolderDialog(QWidget *parent)
     mainLayout->addWidget(mFormatComboBox, row, 1);
     row++;
 
-    QLabel *fileNameLabel = new QLabel(i18n("&Archive File:"), mainWidget);
+    auto fileNameLabel = new QLabel(i18n("&Archive File:"), mainWidget);
     mainLayout->addWidget(fileNameLabel, row, 0);
     mUrlRequester = new KUrlRequester(mainWidget);
     mUrlRequester->setMode(KFile::LocalOnly | KFile::File);
@@ -133,12 +132,8 @@ ArchiveFolderDialog::ArchiveFolderDialog(QWidget *parent)
 bool canRemoveFolder(const Akonadi::Collection &col)
 {
     const QSharedPointer<FolderSettings> folder = FolderSettings::forCollection(col, false);
-    return folder
-           && col.isValid()
-           && !col.isVirtual()
-           && (col.rights() & Akonadi::Collection::CanDeleteCollection)
-           && !folder->isStructural()
-           && !folder->isSystemFolder();
+    return folder && col.isValid() && !col.isVirtual() && (col.rights() & Akonadi::Collection::CanDeleteCollection) && !folder->isStructural()
+        && !folder->isSystemFolder();
 }
 
 void ArchiveFolderDialog::slotRecursiveCheckboxClicked()
@@ -173,12 +168,11 @@ void ArchiveFolderDialog::slotAccepted()
     }
 
     if (!mFolderRequester->hasCollection()) {
-        KMessageBox::information(this, i18n("Please select the folder that should be archived."),
-                                 i18n("No folder selected"));
+        KMessageBox::information(this, i18n("Please select the folder that should be archived."), i18n("No folder selected"));
         return;
     }
 
-    auto *backupJob = new MailCommon::BackupJob(mParentWidget);
+    auto backupJob = new MailCommon::BackupJob(mParentWidget);
     backupJob->setRootFolder(mFolderRequester->collection());
     backupJob->setSaveLocation(mUrlRequester->url());
     backupJob->setArchiveType(static_cast<BackupJob::ArchiveType>(mFormatComboBox->currentIndex()));
@@ -192,12 +186,11 @@ void ArchiveFolderDialog::slotFixFileExtension()
 {
     const int numExtensions = 4;
     // The extensions here are also sorted, like the enum order of BackupJob::ArchiveType
-    const char *extensions[numExtensions] = { ".zip", ".tar", ".tar.bz2", ".tar.gz" };
+    const char *extensions[numExtensions] = {".zip", ".tar", ".tar.bz2", ".tar.gz"};
 
     QString fileName = mUrlRequester->url().path();
     if (fileName.isEmpty()) {
-        fileName = standardArchivePath(mFolderRequester->hasCollection()
-                                       ? mFolderRequester->collection().name() : QString());
+        fileName = standardArchivePath(mFolderRequester->hasCollection() ? mFolderRequester->collection().name() : QString());
     }
 
     QMimeDatabase db;
