@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,13 +7,15 @@
 #ifndef KMAILPLUGINEDITORMANAGERINTERFACE_H
 #define KMAILPLUGINEDITORMANAGERINTERFACE_H
 
-#include <QObject>
-#include <QHash>
 #include <MessageComposer/PluginEditorInterface>
-namespace KPIMTextEdit {
+#include <QHash>
+#include <QObject>
+namespace KPIMTextEdit
+{
 class RichTextEditor;
 }
-namespace MessageComposer {
+namespace MessageComposer
+{
 class PluginEditorInterface;
 class ComposerViewBase;
 }
@@ -23,7 +25,7 @@ class KMailPluginEditorManagerInterface : public QObject
     Q_OBJECT
 public:
     explicit KMailPluginEditorManagerInterface(QObject *parent = nullptr);
-    ~KMailPluginEditorManagerInterface();
+    ~KMailPluginEditorManagerInterface() override;
 
     KPIMTextEdit::RichTextEditor *richTextEditor() const;
     void setRichTextEditor(KPIMTextEdit::RichTextEditor *richTextEditor);
@@ -36,7 +38,7 @@ public:
     KActionCollection *actionCollection() const;
     void setActionCollection(KActionCollection *actionCollection);
 
-    Q_REQUIRED_RESULT QHash<MessageComposer::PluginActionType::Type, QList<QAction *> > actionsType();
+    Q_REQUIRED_RESULT QHash<MessageComposer::PluginActionType::Type, QList<QAction *>> actionsType();
     Q_REQUIRED_RESULT QList<QAction *> actionsType(MessageComposer::PluginActionType::Type type);
     Q_REQUIRED_RESULT QList<QWidget *> statusBarWidgetList();
 
@@ -45,6 +47,7 @@ public:
 
     Q_REQUIRED_RESULT bool processProcessKeyEvent(QKeyEvent *event);
 
+    void setStatusBarWidgetEnabled(MessageComposer::PluginEditorInterface::ApplyOnFieldType type);
 Q_SIGNALS:
     void textSelectionChanged(bool hasSelection);
     void message(const QString &str);
@@ -58,7 +61,7 @@ private:
     QWidget *mParentWidget = nullptr;
     KActionCollection *mActionCollection = nullptr;
     QList<MessageComposer::PluginEditorInterface *> mListPluginInterface;
-    QHash<MessageComposer::PluginActionType::Type, QList<QAction *> > mActionHash;
+    QHash<MessageComposer::PluginActionType::Type, QList<QAction *>> mActionHash;
     QList<QWidget *> mStatusBarWidget;
 };
 
