@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,15 +7,15 @@
 #ifndef INCORRECTIDENTITYFOLDERWARNING_H
 #define INCORRECTIDENTITYFOLDERWARNING_H
 
-#include <KMessageWidget>
 #include "kmail_private_export.h"
+#include <KMessageWidget>
 
 class KMAILTESTS_TESTS_EXPORT IncorrectIdentityFolderWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
     explicit IncorrectIdentityFolderWarning(QWidget *parent = nullptr);
-    ~IncorrectIdentityFolderWarning();
+    ~IncorrectIdentityFolderWarning() override;
 
     void mailTransportIsInvalid();
     void fccIsInvalid();
