@@ -1,14 +1,14 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "folderarchiveaccountinfotest.h"
 #include "../folderarchiveaccountinfo.h"
 #include <AkonadiCore/Collection>
-#include <QTest>
 #include <KSharedConfig>
 #include <QStandardPaths>
+#include <QTest>
 
 FolderArchiveAccountInfoTest::FolderArchiveAccountInfoTest(QObject *parent)
     : QObject(parent)
@@ -16,8 +16,7 @@ FolderArchiveAccountInfoTest::FolderArchiveAccountInfoTest(QObject *parent)
     QStandardPaths::setTestModeEnabled(true);
 }
 
-FolderArchiveAccountInfoTest::~FolderArchiveAccountInfoTest()
-= default;
+FolderArchiveAccountInfoTest::~FolderArchiveAccountInfoTest() = default;
 
 void FolderArchiveAccountInfoTest::shouldHaveDefaultValue()
 {
