@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2012-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-only
 */
@@ -9,7 +9,8 @@
 
 #include <QDialog>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class AkonadiContactEditor;
 }
 
@@ -18,16 +19,16 @@ class IdentityEditVcardDialog : public QDialog
     Q_OBJECT
 public:
     explicit IdentityEditVcardDialog(const QString &fileName, QWidget *parent = nullptr);
-    ~IdentityEditVcardDialog();
+    ~IdentityEditVcardDialog() override;
     /**
-    * @brief loadVcard load vcard in a contact editor
-    * @param vcardFileName
-    */
+     * @brief loadVcard load vcard in a contact editor
+     * @param vcardFileName
+     */
     void loadVcard(const QString &vcardFileName);
     /**
-    * @brief saveVcard
-    * @return The file path for current vcard.
-    */
+     * @brief saveVcard
+     * @return The file path for current vcard.
+     */
     Q_REQUIRED_RESULT QString saveVcard() const;
 
     void reject() override;
