@@ -15,21 +15,21 @@
 #include <KPIMTextEdit/PlainTextEditorWidget>
 #include <MessageViewer/KXFace>
 
+#include <KIO/StoredTransferJob>
 #include <KJobWidgets>
-#include <QComboBox>
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KIO/StoredTransferJob>
+#include <QComboBox>
 
 #include <QCheckBox>
+#include <QFileDialog>
+#include <QFontDatabase>
 #include <QHBoxLayout>
+#include <QImageReader>
 #include <QLabel>
 #include <QPushButton>
 #include <QStackedWidget>
 #include <QVBoxLayout>
-#include <QFontDatabase>
-#include <QImageReader>
-#include <QFileDialog>
 using namespace KContacts;
 using namespace KIO;
 using namespace KMail;
@@ -39,9 +39,9 @@ using namespace KMail;
 XFaceConfigurator::XFaceConfigurator(QWidget *parent)
     : QWidget(parent)
 {
-    auto *vlay = new QVBoxLayout(this);
+    auto vlay = new QVBoxLayout(this);
     vlay->setObjectName(QStringLiteral("main layout"));
-    auto *hlay = new QHBoxLayout();
+    auto hlay = new QHBoxLayout();
     vlay->addLayout(hlay);
 
     // "enable X-Face" checkbox:
@@ -53,8 +53,7 @@ XFaceConfigurator::XFaceConfigurator(QWidget *parent)
     hlay->addWidget(mEnableCheck, Qt::AlignLeft | Qt::AlignVCenter);
 
     mXFaceLabel = new QLabel(this);
-    mXFaceLabel->setWhatsThis(
-        i18n("This is a preview of the picture selected/entered below."));
+    mXFaceLabel->setWhatsThis(i18n("This is a preview of the picture selected/entered below."));
     mXFaceLabel->setFixedSize(48, 48);
     mXFaceLabel->setFrameShape(QFrame::Box);
     hlay->addWidget(mXFaceLabel);
@@ -65,24 +64,20 @@ XFaceConfigurator::XFaceConfigurator(QWidget *parent)
     // "obtain X-Face from" combo and label:
     hlay = new QHBoxLayout(); // inherits spacing
     vlay->addLayout(hlay);
-    auto *sourceCombo = new QComboBox(this);
-    sourceCombo->setWhatsThis(
-        i18n("Click on the widgets below to obtain help on the input methods."));
-    sourceCombo->setEnabled(false);   // since !mEnableCheck->isChecked()
-    sourceCombo->addItems(QStringList()
-                          << i18nc("continuation of \"obtain picture from\"",
-                                   "External Source")
-                          << i18nc("continuation of \"obtain picture from\"",
-                                   "Input Field Below"));
-    QLabel *label = new QLabel(i18n("Obtain pic&ture from:"), this);
+    auto sourceCombo = new QComboBox(this);
+    sourceCombo->setWhatsThis(i18n("Click on the widgets below to obtain help on the input methods."));
+    sourceCombo->setEnabled(false); // since !mEnableCheck->isChecked()
+    sourceCombo->addItems(QStringList() << i18nc("continuation of \"obtain picture from\"", "External Source")
+                                        << i18nc("continuation of \"obtain picture from\"", "Input Field Below"));
+    auto label = new QLabel(i18n("Obtain pic&ture from:"), this);
     label->setBuddy(sourceCombo);
-    label->setEnabled(false);   // since !mEnableCheck->isChecked()
+    label->setEnabled(false); // since !mEnableCheck->isChecked()
     hlay->addWidget(label);
     hlay->addWidget(sourceCombo, 1);
 
     // widget stack that is controlled by the source combo:
-    auto *widgetStack = new QStackedWidget(this);
-    widgetStack->setEnabled(false);   // since !mEnableCheck->isChecked()
+    auto widgetStack = new QStackedWidget(this);
+    widgetStack->setEnabled(false); // since !mEnableCheck->isChecked()
     vlay->addWidget(widgetStack, 1);
     connect(sourceCombo, qOverload<int>(&QComboBox::highlighted), widgetStack, &QStackedWidget::setCurrentIndex);
     connect(sourceCombo, qOverload<int>(&QComboBox::activated), widgetStack, &QStackedWidget::setCurrentIndex);
@@ -90,18 +85,17 @@ XFaceConfigurator::XFaceConfigurator(QWidget *parent)
     connect(mEnableCheck, &QCheckBox::toggled, widgetStack, &QStackedWidget::setEnabled);
     connect(mEnableCheck, &QCheckBox::toggled, label, &QLabel::setEnabled);
     // The focus might be still in the widget that is disabled
-    connect(mEnableCheck, &QAbstractButton::clicked,
-            mEnableCheck, qOverload<>(&QWidget::setFocus));
+    connect(mEnableCheck, &QAbstractButton::clicked, mEnableCheck, qOverload<>(&QWidget::setFocus));
 
     int pageno = 0;
     // page 0: create X-Face from image file or address book entry
-    QWidget *page = new QWidget(widgetStack);
-    widgetStack->insertWidget(pageno, page);   // force sequential numbers (play safe)
-    auto *page_vlay = new QVBoxLayout(page);
+    auto page = new QWidget(widgetStack);
+    widgetStack->insertWidget(pageno, page); // force sequential numbers (play safe)
+    auto page_vlay = new QVBoxLayout(page);
     page_vlay->setContentsMargins({});
     hlay = new QHBoxLayout(); // inherits spacing ??? FIXME really?
     page_vlay->addLayout(hlay);
-    QPushButton *mFromFileBtn = new QPushButton(i18n("Select File..."), page);
+    auto mFromFileBtn = new QPushButton(i18n("Select File..."), page);
     mFromFileBtn->setWhatsThis(
         i18n("Use this to select an image file to create the picture from. "
              "The image should be of high contrast and nearly quadratic shape. "
@@ -109,22 +103,23 @@ XFaceConfigurator::XFaceConfigurator(QWidget *parent)
     mFromFileBtn->setAutoDefault(false);
     page_vlay->addWidget(mFromFileBtn, 1);
     connect(mFromFileBtn, &QPushButton::released, this, &XFaceConfigurator::slotSelectFile);
-    QPushButton *mFromAddrbkBtn = new QPushButton(i18n("Set From Address Book"), page);
+    auto mFromAddrbkBtn = new QPushButton(i18n("Set From Address Book"), page);
     mFromAddrbkBtn->setWhatsThis(
         i18n("You can use a scaled-down version of the picture "
              "you have set in your address book entry."));
     mFromAddrbkBtn->setAutoDefault(false);
     page_vlay->addWidget(mFromAddrbkBtn, 1);
     connect(mFromAddrbkBtn, &QPushButton::released, this, &XFaceConfigurator::slotSelectFromAddressbook);
-    QLabel *label1 = new QLabel(i18n("<qt>KMail can send a small (48x48 pixels), low-quality, "
-                                     "monochrome picture with every message. "
-                                     "For example, this could be a picture of you or a glyph. "
-                                     "It is shown in the recipient's mail client (if supported).</qt>"), page);
+    auto label1 = new QLabel(i18n("<qt>KMail can send a small (48x48 pixels), low-quality, "
+                                  "monochrome picture with every message. "
+                                  "For example, this could be a picture of you or a glyph. "
+                                  "It is shown in the recipient's mail client (if supported).</qt>"),
+                             page);
     label1->setAlignment(Qt::AlignVCenter);
     label1->setWordWrap(true);
     page_vlay->addWidget(label1);
     page_vlay->addStretch();
-    widgetStack->setCurrentIndex(0);   // since sourceCombo->currentItem() == 0
+    widgetStack->setCurrentIndex(0); // since sourceCombo->currentItem() == 0
 
     // page 1: input field for direct entering
     ++pageno;
@@ -139,9 +134,10 @@ XFaceConfigurator::XFaceConfigurator(QWidget *parent)
     mTextEdit->editor()->setFont(QFontDatabase::systemFont(QFontDatabase::FixedFont));
     mTextEdit->editor()->setWordWrapMode(QTextOption::WrapAnywhere);
     mTextEdit->editor()->setSearchSupport(false);
-    QLabel *label2 = new QLabel(i18n("Examples are available at <a "
-                                     "href=\"https://ace.home.xs4all.nl/X-Faces/\">"
-                                     "https://ace.home.xs4all.nl/X-Faces/</a>."), page);
+    auto label2 = new QLabel(i18n("Examples are available at <a "
+                                  "href=\"https://ace.home.xs4all.nl/X-Faces/\">"
+                                  "https://ace.home.xs4all.nl/X-Faces/</a>."),
+                             page);
     label2->setOpenExternalLinks(true);
     label2->setTextInteractionFlags(Qt::TextBrowserInteraction);
 
@@ -150,8 +146,7 @@ XFaceConfigurator::XFaceConfigurator(QWidget *parent)
     connect(mTextEdit->editor(), &KPIMTextEdit::PlainTextEditor::textChanged, this, &XFaceConfigurator::slotUpdateXFace);
 }
 
-XFaceConfigurator::~XFaceConfigurator()
-= default;
+XFaceConfigurator::~XFaceConfigurator() = default;
 
 bool XFaceConfigurator::isXFaceEnabled() const
 {
@@ -211,7 +206,7 @@ void XFaceConfigurator::slotSelectFromAddressbook()
     const Identity defaultIdentity = manager.defaultIdentity();
     const QString email = defaultIdentity.primaryEmailAddress().toLower();
 
-    auto *job = new Akonadi::ContactSearchJob(this);
+    auto job = new Akonadi::ContactSearchJob(this);
     job->setLimit(1);
     job->setQuery(Akonadi::ContactSearchJob::Email, email, Akonadi::ContactSearchJob::ExactMatch);
     connect(job, &Akonadi::ContactSearchJob::result, this, &XFaceConfigurator::slotDelayedSelectFromAddressbook);
