@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -8,14 +8,13 @@
 #define CREATEFORWARDMESSAGEJOB_H
 
 #include "kmail_private_export.h"
+#include <AkonadiCore/Item>
+#include <KMime/Message>
+#include <MessageComposer/MessageFactoryNG>
 #include <QObject>
 #include <QUrl>
-#include <KMime/Message>
-#include <AkonadiCore/Item>
-#include <MessageComposer/MessageFactoryNG>
 
-struct KMAILTESTS_TESTS_EXPORT CreateForwardMessageJobSettings
-{
+struct KMAILTESTS_TESTS_EXPORT CreateForwardMessageJobSettings {
     QUrl url;
     Akonadi::Item item;
     KMime::Message::Ptr msg = nullptr;
@@ -29,7 +28,7 @@ class KMAILTESTS_TESTS_EXPORT CreateForwardMessageJob : public QObject
     Q_OBJECT
 public:
     explicit CreateForwardMessageJob(QObject *parent = nullptr);
-    ~CreateForwardMessageJob();
+    ~CreateForwardMessageJob() override;
     void start();
 
     void setSettings(const CreateForwardMessageJobSettings &value);
