@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,17 +7,15 @@
 #ifndef CREATEREPLYMESSAGEJOB_H
 #define CREATEREPLYMESSAGEJOB_H
 
-#include <QObject>
 #include "kmail_private_export.h"
 #include <AkonadiCore/Item>
 #include <KMime/Message>
 #include <MessageComposer/MessageFactoryNG>
+#include <QObject>
 #include <QUrl>
 
-struct KMAILTESTS_TESTS_EXPORT CreateReplyMessageJobSettings
-{
-    CreateReplyMessageJobSettings()
-    = default;
+struct KMAILTESTS_TESTS_EXPORT CreateReplyMessageJobSettings {
+    CreateReplyMessageJobSettings() = default;
 
     QUrl url;
     QString selection;
@@ -34,7 +32,7 @@ class KMAILTESTS_TESTS_EXPORT CreateReplyMessageJob : public QObject
     Q_OBJECT
 public:
     explicit CreateReplyMessageJob(QObject *parent = nullptr);
-    ~CreateReplyMessageJob();
+    ~CreateReplyMessageJob() override;
 
     void start();
 
