@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,8 @@
 #include <QObject>
 class QWidget;
 class QItemSelectionModel;
-namespace KPIM {
+namespace KPIM
+{
 class ProgressItem;
 }
 class KJob;
@@ -19,7 +20,7 @@ class RemoveDuplicateMailJob : public QObject
     Q_OBJECT
 public:
     explicit RemoveDuplicateMailJob(QItemSelectionModel *selectionModel, QWidget *widget, QObject *parent = nullptr);
-    ~RemoveDuplicateMailJob();
+    ~RemoveDuplicateMailJob() override;
 
     void start();
 
