@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,11 +7,14 @@
 #ifndef CHECKINDEXINGJOB_H
 #define CHECKINDEXINGJOB_H
 
-#include <QObject>
 #include <AkonadiCore/Collection>
-namespace Akonadi {
-namespace Search {
-namespace PIM {
+#include <QObject>
+namespace Akonadi
+{
+namespace Search
+{
+namespace PIM
+{
 class IndexedItems;
 }
 }
@@ -22,7 +25,7 @@ class CheckIndexingJob : public QObject
     Q_OBJECT
 public:
     explicit CheckIndexingJob(Akonadi::Search::PIM::IndexedItems *indexedItems, QObject *parent = nullptr);
-    ~CheckIndexingJob();
+    ~CheckIndexingJob() override;
 
     void setCollection(const Akonadi::Collection &col);
 
