@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-only
  */
@@ -14,14 +14,7 @@ class KMSearchMessageModel : public Akonadi::MessageModel
     Q_OBJECT
 
 public:
-    enum Column {
-        Collection,
-        Subject,
-        Sender,
-        Receiver,
-        Date,
-        Size
-    };
+    enum Column { Collection, Subject, Sender, Receiver, Date, Size };
     explicit KMSearchMessageModel(Akonadi::Monitor *monitor, QObject *parent = nullptr);
     ~KMSearchMessageModel() override;
 
