@@ -3,7 +3,7 @@
  * SPDX-FileCopyrightText: 1996-1998 Stefan Taferner <taferner@kde.org>
  * SPDX-FileCopyrightText: 2001 Aaron J. Seigo <aseigo@kde.org>
  * SPDX-FileCopyrightText: 2010 Till Adam <adam@kde.org>
- * SPDX-FileCopyrightText: 2011-2020 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  *
@@ -12,50 +12,50 @@
 #include "searchwindow.h"
 #include "incompleteindexdialog.h"
 
-#include <MailCommon/FolderRequester>
 #include "kmcommands.h"
 #include "kmkernel.h"
 #include "kmmainwidget.h"
+#include "kmsearchmessagemodel.h"
+#include "searchdescriptionattribute.h"
+#include "searchpatternwarning.h"
+#include <MailCommon/FolderRequester>
+#include <MailCommon/FolderTreeView>
 #include <MailCommon/MailKernel>
 #include <MailCommon/SearchPatternEdit>
-#include "searchdescriptionattribute.h"
-#include <MailCommon/FolderTreeView>
-#include "kmsearchmessagemodel.h"
-#include "searchpatternwarning.h"
-#include <PimCommonAkonadi/SelectMultiCollectionDialog>
 #include <PimCommon/PimUtil>
+#include <PimCommonAkonadi/SelectMultiCollectionDialog>
 
-#include <AkonadiCore/CollectionModifyJob>
-#include <AkonadiCore/CollectionFetchJob>
-#include <AkonadiWidgets/EntityTreeView>
-#include <AkonadiCore/persistentsearchattribute.h>
-#include <AkonadiCore/SearchCreateJob>
-#include <AkonadiCore/ChangeRecorder>
-#include <AkonadiWidgets/standardactionmanager.h>
-#include <AkonadiCore/EntityMimeTypeFilterModel>
-#include <AkonadiCore/CachePolicy>
-#include <AkonadiCore/EntityHiddenAttribute>
-#include <KActionMenu>
 #include "kmail_debug.h"
+#include <AkonadiCore/CachePolicy>
+#include <AkonadiCore/ChangeRecorder>
+#include <AkonadiCore/CollectionFetchJob>
+#include <AkonadiCore/CollectionModifyJob>
+#include <AkonadiCore/EntityHiddenAttribute>
+#include <AkonadiCore/EntityMimeTypeFilterModel>
+#include <AkonadiCore/SearchCreateJob>
+#include <AkonadiCore/persistentsearchattribute.h>
+#include <AkonadiSearch/PIM/indexeditems.h>
+#include <AkonadiWidgets/EntityTreeView>
+#include <AkonadiWidgets/standardactionmanager.h>
+#include <KActionMenu>
+#include <KMessageBox>
+#include <KStandardAction>
+#include <KStandardGuiItem>
 #include <QIcon>
 #include <QSortFilterProxyModel>
 #include <entitytreemodel.h>
 #include <entitytreeview.h>
 #include <kmime/kmime_message.h>
-#include <KStandardAction>
-#include <KStandardGuiItem>
-#include <KMessageBox>
-#include <AkonadiSearch/PIM/indexeditems.h>
 
 #include <QCheckBox>
 #include <QCloseEvent>
 #include <QCursor>
+#include <QDialogButtonBox>
 #include <QHeaderView>
 #include <QKeyEvent>
 #include <QMenu>
-#include <QVBoxLayout>
-#include <QDialogButtonBox>
 #include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace KPIM;
 using namespace MailCommon;
@@ -68,16 +68,16 @@ SearchWindow::SearchWindow(KMMainWidget *widget, const Akonadi::Collection &coll
 {
     setWindowTitle(i18nc("@title:window", "Find Messages"));
 
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
 
-    QWidget *topWidget = new QWidget;
-    auto *lay = new QVBoxLayout(topWidget);
+    auto topWidget = new QWidget;
+    auto lay = new QVBoxLayout(topWidget);
     lay->setContentsMargins({});
     mSearchPatternWidget = new SearchPatternWarning;
     lay->addWidget(mSearchPatternWidget);
     mainLayout->addWidget(topWidget);
 
-    QWidget *searchWidget = new QWidget(this);
+    auto searchWidget = new QWidget(this);
     mUi.setupUi(searchWidget);
 
     lay->addWidget(searchWidget);
@@ -116,10 +116,8 @@ SearchWindow::SearchWindow(KMMainWidget *widget, const Akonadi::Collection &coll
     mUi.mLbxMatches->setSortingEnabled(true);
 
     connect(mUi.mLbxMatches, &Akonadi::EntityTreeView::customContextMenuRequested, this, &SearchWindow::slotContextMenuRequested);
-    connect(mUi.mLbxMatches, qOverload<const Akonadi::Item &>(&Akonadi::EntityTreeView::doubleClicked),
-            this, &SearchWindow::slotViewMsg);
-    connect(mUi.mLbxMatches, qOverload<const Akonadi::Item &>(&Akonadi::EntityTreeView::currentChanged),
-            this, &SearchWindow::slotCurrentChanged);
+    connect(mUi.mLbxMatches, qOverload<const Akonadi::Item &>(&Akonadi::EntityTreeView::doubleClicked), this, &SearchWindow::slotViewMsg);
+    connect(mUi.mLbxMatches, qOverload<const Akonadi::Item &>(&Akonadi::EntityTreeView::currentChanged), this, &SearchWindow::slotCurrentChanged);
     connect(mUi.selectMultipleFolders, &QPushButton::clicked, this, &SearchWindow::slotSelectMultipleFolders);
 
     connect(KMKernel::self()->folderCollectionMonitor(), &Akonadi::Monitor::collectionStatisticsChanged, this, &SearchWindow::updateCollectionStatistic);
@@ -142,14 +140,14 @@ SearchWindow::SearchWindow(KMMainWidget *widget, const Akonadi::Collection &coll
     connect(mUi.mButtonBox->button(QDialogButtonBox::Close), &QPushButton::clicked, this, &SearchWindow::slotClose);
 
     // give focus to the value field of the first search rule
-    auto *r = mUi.mPatternEdit->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
+    auto r = mUi.mPatternEdit->findChild<KLineEdit *>(QStringLiteral("regExpLineEdit"));
     if (r) {
         r->setFocus();
     } else {
         qCDebug(KMAIL_LOG) << "SearchWindow: regExpLineEdit not found";
     }
 
-    //set up actions
+    // set up actions
     KActionCollection *ac = actionCollection();
     mReplyAction = new QAction(QIcon::fromTheme(QStringLiteral("mail-reply-sender")), i18n("&Reply..."), this);
     actionCollection()->addAction(QStringLiteral("search_reply"), mReplyAction);
@@ -167,9 +165,7 @@ SearchWindow::SearchWindow(KMMainWidget *widget, const Akonadi::Collection &coll
     actionCollection()->addAction(QStringLiteral("search_message_forward"), mForwardActionMenu);
     connect(mForwardActionMenu, &KActionMenu::triggered, this, &SearchWindow::slotForwardMsg);
 
-    mForwardInlineAction = new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")),
-                                       i18nc("@action:inmenu Forward message inline.", "&Inline..."),
-                                       this);
+    mForwardInlineAction = new QAction(QIcon::fromTheme(QStringLiteral("mail-forward")), i18nc("@action:inmenu Forward message inline.", "&Inline..."), this);
     actionCollection()->addAction(QStringLiteral("search_message_forward_inline"), mForwardInlineAction);
     connect(mForwardInlineAction, &QAction::triggered, this, &SearchWindow::slotForwardMsg);
 
@@ -251,7 +247,7 @@ void SearchWindow::createSearchModel()
     mResultModel = new KMSearchMessageModel(monitor, this);
     mResultModel->setCollectionMonitored(mFolder);
     monitor->setParent(mResultModel);
-    auto *sortproxy = new QSortFilterProxyModel(mResultModel);
+    auto sortproxy = new QSortFilterProxyModel(mResultModel);
     sortproxy->setDynamicSortFilter(true);
     sortproxy->setSortRole(Qt::EditRole);
     sortproxy->setFilterCaseSensitivity(Qt::CaseInsensitive);
@@ -269,7 +265,7 @@ void SearchWindow::createSearchModel()
     mUi.mLbxMatches->header()->setSortIndicator(2, Qt::DescendingOrder);
     mUi.mLbxMatches->header()->setStretchLastSection(false);
     mUi.mLbxMatches->header()->restoreState(mHeaderState);
-    //mUi.mLbxMatches->header()->setResizeMode( 3, QHeaderView::Stretch );
+    // mUi.mLbxMatches->header()->setResizeMode( 3, QHeaderView::Stretch );
     if (!mAkonadiStandardAction) {
         mAkonadiStandardAction = new Akonadi::StandardMailActionManager(actionCollection(), this);
     }
@@ -279,10 +275,10 @@ void SearchWindow::createSearchModel()
 
 void SearchWindow::setEnabledSearchButton(bool)
 {
-    //Make sure that button is enable
-    //Before when we selected a folder == "Local Folder" as that it was not a folder
-    //search button was disable, and when we select "Search in all local folder"
-    //Search button was never enabled :(
+    // Make sure that button is enable
+    // Before when we selected a folder == "Local Folder" as that it was not a folder
+    // search button was disable, and when we select "Search in all local folder"
+    // Search button was never enabled :(
     mSearchButton->setEnabled(true);
 }
 
@@ -376,10 +372,10 @@ void SearchWindow::slotSearch()
         doSearch();
         return;
     }
-    //We're going to try to create a new search folder, let's ensure first the name is not yet used.
+    // We're going to try to create a new search folder, let's ensure first the name is not yet used.
 
-    //Fetch all search collections
-    Akonadi::CollectionFetchJob *fetchJob = new Akonadi::CollectionFetchJob(Akonadi::Collection(1), Akonadi::CollectionFetchJob::FirstLevel);
+    // Fetch all search collections
+    auto fetchJob = new Akonadi::CollectionFetchJob(Akonadi::Collection(1), Akonadi::CollectionFetchJob::FirstLevel);
     connect(fetchJob, &Akonadi::CollectionFetchJob::result, this, &SearchWindow::slotSearchCollectionsFetched);
 }
 
@@ -388,7 +384,7 @@ void SearchWindow::slotSearchCollectionsFetched(KJob *job)
     if (job->error()) {
         qCWarning(KMAIL_LOG) << job->errorString();
     }
-    auto *fetchJob = static_cast<Akonadi::CollectionFetchJob *>(job);
+    auto fetchJob = static_cast<Akonadi::CollectionFetchJob *>(job);
     const Akonadi::Collection::List lstCol = fetchJob->collections();
     for (const Akonadi::Collection &col : lstCol) {
         if (col.name() == mUi.mSearchFolderEdt->text()) {
@@ -491,7 +487,7 @@ void SearchWindow::doSearch()
 
     if (!mFolder.isValid()) {
         qCDebug(KMAIL_LOG) << " create new folder " << mUi.mSearchFolderEdt->text();
-        Akonadi::SearchCreateJob *searchJob = new Akonadi::SearchCreateJob(mUi.mSearchFolderEdt->text(), mQuery, this);
+        auto searchJob = new Akonadi::SearchCreateJob(mUi.mSearchFolderEdt->text(), mQuery, this);
         searchJob->setSearchMimeTypes(QStringList() << QStringLiteral("message/rfc822"));
         searchJob->setSearchCollections(searchCollections);
         searchJob->setRecursive(recursive);
@@ -499,7 +495,7 @@ void SearchWindow::doSearch()
         mSearchJob = searchJob;
     } else {
         qCDebug(KMAIL_LOG) << " use existing folder " << mFolder.id();
-        auto *attribute = new Akonadi::PersistentSearchAttribute();
+        auto attribute = new Akonadi::PersistentSearchAttribute();
         mFolder.setContentMimeTypes(QStringList() << QStringLiteral("message/rfc822"));
         attribute->setQueryString(QString::fromLatin1(mQuery.toJSON()));
         attribute->setQueryCollections(searchCollections);
@@ -529,9 +525,9 @@ void SearchWindow::searchDone(KJob *job)
         mUi.mSearchFolderEdt->setEnabled(true);
         mUi.mStatusLbl->setText(i18n("Search failed."));
     } else {
-        if (const auto *searchJob = qobject_cast<Akonadi::SearchCreateJob *>(job)) {
+        if (const auto searchJob = qobject_cast<Akonadi::SearchCreateJob *>(job)) {
             mFolder = searchJob->createdCollection();
-        } else if (const auto *modifyJob = qobject_cast<Akonadi::CollectionModifyJob *>(job)) {
+        } else if (const auto modifyJob = qobject_cast<Akonadi::CollectionModifyJob *>(job)) {
             mFolder = modifyJob->collection();
         }
         /// TODO: cope better with cases where this fails
@@ -564,7 +560,7 @@ void SearchWindow::searchDone(KJob *job)
         }
         searchDescription->setRecursive(mUi.mChkSubFolders->isChecked());
         new Akonadi::CollectionModifyJob(mFolder, this);
-        auto *fetch = new Akonadi::CollectionFetchJob(mFolder, Akonadi::CollectionFetchJob::Base, this);
+        auto fetch = new Akonadi::CollectionFetchJob(mFolder, Akonadi::CollectionFetchJob::Base, this);
         fetch->fetchScope().setIncludeStatistics(true);
         connect(fetch, &KJob::result, this, &SearchWindow::slotCollectionStatisticsRetrieved);
 
@@ -584,7 +580,7 @@ void SearchWindow::searchDone(KJob *job)
 
 void SearchWindow::slotCollectionStatisticsRetrieved(KJob *job)
 {
-    auto *fetch = qobject_cast<Akonadi::CollectionFetchJob *>(job);
+    auto fetch = qobject_cast<Akonadi::CollectionFetchJob *>(job);
     if (!fetch || fetch->error()) {
         return;
     }
@@ -621,7 +617,7 @@ void SearchWindow::closeEvent(QCloseEvent *event)
 {
     if (mSearchJob) {
         mCloseRequested = true;
-        //Cancel search in progress
+        // Cancel search in progress
         mSearchJob->kill(KJob::Quietly);
         mSearchJob->deleteLater();
         mSearchJob = nullptr;
@@ -650,7 +646,7 @@ void SearchWindow::renameSearchFolder()
         const QString oldFolderName = mFolder.name();
         if (oldFolderName != name) {
             mFolder.setName(name);
-            auto *job = new Akonadi::CollectionModifyJob(mFolder, this);
+            auto job = new Akonadi::CollectionModifyJob(mFolder, this);
             job->setProperty("oldfoldername", oldFolderName);
             connect(job, &Akonadi::CollectionModifyJob::result, this, &SearchWindow::slotSearchFolderRenameDone);
         }
@@ -663,9 +659,11 @@ void SearchWindow::slotSearchFolderRenameDone(KJob *job)
     Q_ASSERT(job);
     if (job->error()) {
         qCWarning(KMAIL_LOG) << "Job failed:" << job->errorText();
-        KMessageBox::information(this, i18n("There was a problem renaming your search folder. "
-                                            "A common reason for this is that another search folder "
-                                            "with the same name already exists. Error returned \"%1\".", job->errorText()));
+        KMessageBox::information(this,
+                                 i18n("There was a problem renaming your search folder. "
+                                      "A common reason for this is that another search folder "
+                                      "with the same name already exists. Error returned \"%1\".",
+                                      job->errorText()));
         mUi.mSearchFolderEdt->blockSignals(true);
         mUi.mSearchFolderEdt->setText(job->property("oldfoldername").toString());
         mUi.mSearchFolderEdt->blockSignals(false);
@@ -820,13 +818,13 @@ void SearchWindow::slotForwardAttachedMsg()
 
 void SearchWindow::slotSaveMsg()
 {
-    KMSaveMsgCommand *saveCommand = new KMSaveMsgCommand(this, selectedMessages());
+    auto saveCommand = new KMSaveMsgCommand(this, selectedMessages());
     saveCommand->start();
 }
 
 void SearchWindow::slotSaveAttachments()
 {
-    KMSaveAttachmentsCommand *saveCommand = new KMSaveAttachmentsCommand(this, selectedMessages(), nullptr);
+    auto saveCommand = new KMSaveAttachmentsCommand(this, selectedMessages(), nullptr);
     saveCommand->start();
 }
 
@@ -899,7 +897,7 @@ QVector<qint64> SearchWindow::checkIncompleteIndex(const Akonadi::Collection::Li
     enableGUI();
     mUi.mProgressIndicator->hide();
     mUi.mStatusLbl->setText(i18n("Checking index status..."));
-    //Fetch collection ?
+    // Fetch collection ?
     for (const Akonadi::Collection &col : qAsConst(cols)) {
         const qlonglong num = KMKernel::self()->indexedItems()->indexedItems((qlonglong)col.id());
         if (col.statistics().count() != num) {
@@ -922,8 +920,7 @@ Akonadi::Collection::List SearchWindow::searchCollectionsRecursive(const Akonadi
             }
         } else {
             const Akonadi::Collection collection = etm->data(colIdx, Akonadi::EntityTreeModel::CollectionRole).value<Akonadi::Collection>();
-            if (!collection.hasAttribute<Akonadi::EntityHiddenAttribute>()
-                && collection.cachePolicy().localParts().contains(QLatin1String("RFC822"))) {
+            if (!collection.hasAttribute<Akonadi::EntityHiddenAttribute>() && collection.cachePolicy().localParts().contains(QLatin1String("RFC822"))) {
                 result.push_back(collection);
             }
         }
