@@ -14,7 +14,7 @@ class UndoSendCreateJobTest : public QObject
     Q_OBJECT
 public:
     explicit UndoSendCreateJobTest(QObject *parent = nullptr);
-    ~UndoSendCreateJobTest() = default;
+    ~UndoSendCreateJobTest() override = default;
 private Q_SLOTS:
     void shouldHaveDefaultValues();
 };
