@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2014-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,21 +7,21 @@
 #include "displaymessageformatactionmenu.h"
 
 #include <KLocalizedString>
+#include <KToggleAction>
 #include <QAction>
 #include <QMenu>
-#include <KToggleAction>
 
 DisplayMessageFormatActionMenu::DisplayMessageFormatActionMenu(QObject *parent)
     : KActionMenu(parent)
 {
     setText(i18n("Message Default Format"));
     delete menu();
-    auto *subMenu = new QMenu;
+    auto subMenu = new QMenu;
     setMenu(subMenu);
 
-    auto *actionGroup = new QActionGroup(this);
+    auto actionGroup = new QActionGroup(this);
 
-    KToggleAction *act = new KToggleAction(i18n("Prefer &HTML to Plain Text"), this);
+    auto act = new KToggleAction(i18n("Prefer &HTML to Plain Text"), this);
     act->setObjectName(QStringLiteral("prefer-html-action"));
     act->setData(MessageViewer::Viewer::Html);
     actionGroup->addAction(act);
@@ -42,8 +42,7 @@ DisplayMessageFormatActionMenu::DisplayMessageFormatActionMenu(QObject *parent)
     updateMenu();
 }
 
-DisplayMessageFormatActionMenu::~DisplayMessageFormatActionMenu()
-= default;
+DisplayMessageFormatActionMenu::~DisplayMessageFormatActionMenu() = default;
 
 void DisplayMessageFormatActionMenu::slotChangeDisplayMessageFormat(QAction *act)
 {
