@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2015-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,10 @@
 #ifndef KACTIONMENUTRANSPORT_H
 #define KACTIONMENUTRANSPORT_H
 
-#include <KActionMenu>
 #include "kmail_private_export.h"
-namespace MailTransport {
+#include <KActionMenu>
+namespace MailTransport
+{
 class Transport;
 }
 
@@ -18,7 +19,7 @@ class KMAILTESTS_TESTS_EXPORT KActionMenuTransport : public KActionMenu
     Q_OBJECT
 public:
     explicit KActionMenuTransport(QObject *parent = nullptr);
-    ~KActionMenuTransport();
+    ~KActionMenuTransport() override;
 
 Q_SIGNALS:
     void transportSelected(MailTransport::Transport *transport);
